@@ -75,7 +75,7 @@ class Api:
         """Fetch from the Launch endpoint"""
         return await AsyncLaunch.fetch(self.network, **kwargs)
 
-    async def async_upcoming_launches(self, num: int) -> List[AsyncUpcomingLaunch]:
+    async def async_next_launches(self, num: int) -> List[AsyncUpcomingLaunch]:
         """
         Get the next {num} launches.
 
