@@ -241,17 +241,6 @@ class Launch(BaseModel):
 
         super().__init__(network, param_translations, proper_name)
 
-    @classmethod
-    def next(cls, network: Network, num: int) -> List["Launch"]:
-        """
-        A simple abstraction method to get the next {num} launches.
-
-        :param network: An instance of launchlibrary.Api
-
-        :param num: a number for the number of launches
-        """
-        return cls.fetch(network, next=num, status=1)
-
     def _postprocess(self):
         """Changes times to the datetime format."""
         for time_name in ["windowstart", "windowend", "net"]:
@@ -269,6 +258,25 @@ class Launch(BaseModel):
         return self.net > other.net
 
 
+class UpcomingLaunch(Launch):
+    _nested_name = "launches"
+    _endpoint_name = "launch/upcoming"
+
+    def __init__(self, network: Network):
+        super().__init__(network)
+
+    @classmethod
+    def next(cls, network: Network, num: int) -> List["UpcomingLaunch"]:
+        """
+        A simple abstraction method to get the next {num} launches.
+
+        :param network: An instance of launchlibrary.Api
+
+        :param num: a number for the number of launches
+        """
+        return cls.fetch(network, next=num, status=1)
+
+
 class Pad(BaseModel):
     """A class representing a pad object."""
 
